@@ -18,8 +18,8 @@ program = os.path.basename(sys.argv[0])
 
 shared_base = '/usr/share/pycentral/'
 shared_base2 = '/usr/share/pyshared/'
-pycentral_version = '0.6.5ubuntu1'
-req_pycentral_version = '0.6.5'
+pycentral_version = '0.6.7ubuntu1'
+req_pycentral_version = '0.6.7'
 
 def samefs(path1, path2):
     if not (os.path.exists(path1) and os.path.exists(path2)):
@@ -131,7 +131,7 @@ class PythonRuntime:
             if rv:
                 raise PyCentralError
 
-    def byte_compile(self, files, bc_option, exclude=None, ignore_errors=False):
+    def byte_compile(self, files, bc_option, exclude=None, ignore_errors=False, force=False):
         errors = False
         if exclude:
             rx = re.compile(exclude)
@@ -155,6 +155,8 @@ class PythonRuntime:
         cmd = [self.interp, '/usr/bin/py_compilefiles', '-q']
         if ignore_errors:
             cmd.append('-i')
+        if force:
+            cmd.append('-f')
         cmd.append('-')
         for opt in ('standard', 'optimize'):
             if not opt in bc_option:
@@ -1092,7 +1094,7 @@ class DebPackage:
         # byte compile with the default runtime for the package
         if self.private_files:
             self.default_runtime.byte_compile(self.private_files,
-                                              bc_option, exclude_regex)
+                                              bc_option, exclude_regex, force=True)
 
 known_actions = {}
 def register_action(action_class):
@@ -1503,9 +1505,22 @@ class ActionRuntimeRemove(Action):
         packages = [(p, v) for p, v in read_dpkg_status(verbose=True)
                     if not p in (self.rtname, self.rtname+'-minimal')]
         needed_packages = []
+        import subprocess
         for pkgname, vstring in packages:
+            if not os.path.exists('/var/lib/dpkg/info/%s.list' % pkgname):
+                # already removed, but /var/lib/dpkg/status not yet updated
+                continue
+            cmd = ['/usr/bin/dpkg-query', '-W', '-f', '${Status}\n', pkgname]
+            p = subprocess.Popen(cmd, bufsize=1,
+                                 shell=False, stdout=subprocess.PIPE)
+            fd = p.stdout
+            status = fd.readline().strip().split()
+            fd.close()
+            if not 'installed' in status:
+                # already removed, but /var/lib/dpkg/status not yet updated
+                continue
             try:
-                requested = list(pyversions.requested_versions(vstring, version_only=True))
+                requested = list(pyversions.requested_versions_for_runtime(vstring, version_only=True))
             except ValueError:
                 logging.info('\tunsupported for %s: %s (%s)' % (self.rtname, pkgname, vstring))
                 continue
